diff projects/filter_FIR/render.cpp @ 56:3c3a1357657d newapi

Further API update to name three primary functions setup(), render() and cleanup(). Changed include paths so now can #include <BeagleRT.h>. Removed stale pru_rtaudio.bin file as this is now done as pru_rtaudio_bin.h. Updated examples to new API and fixed minor compiler warnings along the way. Network example needs further attention to compile.
author andrewm
date Wed, 15 Jul 2015 12:10:51 +0100
parents a6d223473ea2
children 5433c83ce04e
line wrap: on
line diff
--- a/projects/filter_FIR/render.cpp	Mon Jun 15 18:16:00 2015 +0100
+++ b/projects/filter_FIR/render.cpp	Wed Jul 15 12:10:51 2015 +0100
@@ -6,10 +6,8 @@
  */
 
 
-#include "../../include/BeagleRT.h"	// to schedule lower prio parallel process
-#include <rtdk.h>
+#include <BeagleRT.h>
 #include <cmath>
-#include <stdio.h>
 #include <NE10.h>					// neon library
 #include "SampleData.h"
 #include "FIRfilter.h"
@@ -26,14 +24,13 @@
 
 void initialise_filter(BeagleRTContext *context);
 
-
 // Task for handling the update of the frequencies using the matrix
 AuxiliaryTask gTriggerSamplesTask;
 
 bool initialise_trigger();
 void trigger_samples();
 
 // initialise_render() is called once before the audio rendering starts.
 // Use it to perform any initialisation and allocation which is dependent
 // on the period size or sample rate.
 //
@@ -42,7 +39,7 @@
 //
 // Return true on success; returning false halts the program.
 
-bool initialise_render(BeagleRTContext *context, void *userData)
+bool setup(BeagleRTContext *context, void *userData)
 {
 
 	// Retrieve a parameter passed in from the initAudio() call
@@ -151,10 +148,10 @@
 
 
 
 // cleanup_render() is called once at the end, after the audio has stopped.
 // Release any resources that were allocated in initialise_render().
 
-void cleanup_render(BeagleRTContext *context, void *userData)
+void cleanup(BeagleRTContext *context, void *userData)
 {
 	delete[] gSampleData.samples;
@@ -26,14 +24,13 @@
 void trigger_samples();
 
-// initialise_render() is called once before the audio rendering starts.
+// setup() is called once before the audio rendering starts.
 // Use it to perform any initialisation and allocation which is dependent
 // on the period size or sample rate.
@@ -151,10 +148,10 @@
 
 
-// cleanup_render() is called once at the end, after the audio has stopped.
-// Release any resources that were allocated in initialise_render().
+// cleanup() is called once at the end, after the audio has stopped.
+// Release any resources that were allocated in setup().
 